==> haskell-ed25519-0.0.5.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-J1hYKylECALHDf0AVFqTV7
key:                  ed25519-0.0.5.0-J1hYKylECALHDf0AVFqTV7
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  3019d814e967fbdde054d578d5ba72df
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ed25519
hs-libraries:         HSed25519-0.0.5.0-J1hYKylECALHDf0AVFqTV7
depends:              base-4.16.4.0 bytestring-0.11.4.0 ghc-prim-0.8.0
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ed25519-0.0.5.0-26-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ed25519
version:              0.0.5.0
visibility:           public
id:                   ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
key:                  ed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
license:              MIT
copyright:            Copyright (c) Austin Seipp 2013-2015
maintainer:           Austin Seipp <aseipp@pobox.com>
author:               Austin Seipp
homepage:             http://thoughtpolice.github.com/hs-ed25519
synopsis:             Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.

category:             Cryptography
abi:                  037568850411608371671296c4c1a44b
exposed:              True
exposed-modules:      Crypto.Sign.Ed25519
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ed25519-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ed25519-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ed25519
hs-libraries:         HSed25519-0.0.5.0-8644XuUf7h2DKMAvPBqI1l
depends:              base-4.17.2.1 bytestring-0.11.5.3 ghc-prim-0.9.1
haddock-interfaces:   /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html:         /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
